% =============================================================================
%
% PowAuto.m CBPrice 24-10-15
%
% Octave test file for 3302 NL Curve Fitting
%
% Auto Fit of y = A/x^k from source file. eg y = A ./ (x .^B)
%
% Parameter and scaling options for data sets (in this order) 'powData1.csv'
% 'webLinks1.csv', 'tomSawyer.csv'
%
% =============================================================================

filename = input('Input filename'); %must add ' at start and end of name tuped.
delimiterIn = ',';
headerlinesIn = 0;
A = importdata(filename,delimiterIn,headerlinesIn); 

x = A(:,1);
y = A(:,2);
z = log(y);
xx = log(x);

figure(1);
plot(x,y,'o');
figure(2);
plot(log(x),z,'o');

modelfun = @(p,x) p(1) ./( x .^ p(2));

% YOU MUST ADJUST THE FOLLOWING LINE
%startingVals = [4.5,2]; %Estimates for all parameters in the modelfun
%startingVals = [106649769,2]; %Estimates for all parameters in the modelfun
startingVals = [4000,0.8];
[coefEsts,R,J] = nlinfit(x,y,modelfun,startingVals);
disp(' ');
disp('Estimated Coefficienst'); disp(coefEsts);

% YOU MUST ADJUST THE FOLLOWING LINE
%xgrid = linspace(0.5,4,100); %Start, end and nr of points. Refer to data
%xgrid = linspace(1,600,100); %Start, end and nr of points. Refer to data
xgrid = linspace(1,100,100); %Start, end and nr of points. Refer to data

figure(1);
line(xgrid,modelfun(coefEsts,xgrid), 'Color','r');

disp(' ' );
disp('95% confidence intervals for parameters');
bci = nlparci(coefEsts,R,J);
disp(bci);

f = modelfun(coefEsts,x);

figure(2);
plot(log(x),z,'o',log(x),log(f),'r');

disp(' ' );
disp('rms error = ');
err = y - f;
err2 = err.^2;
mse = mean(err2);
rmse = sqrt(mse);
disp(rmse);

ssResid = sum(R.^2);
ssTotal = sum((y-mean(y)).^2);
r2 = 1 - (ssResid/ssTotal);
disp('  ');
disp('r2 value = '); disp(r2);