% =============================================================================
%
% SigAuto.m CBPrice 24-10-15
%
% Octave test file for 3302 NL Curve Fitting
%
% Auto Fit of y = A/(1 + exp(-B*(x - X)))
%
% Parameter and scaling options for data sets (in this order) 'pop.csv, mobile.csv
%
% =============================================================================


filename = input('Input filename'); %must add ' at start and end of name tuped.
delimiterIn = ',';
headerlinesIn = 0;
A = importdata(filename,delimiterIn,headerlinesIn); 

x = A(:,1);
y = A(:,2);

plot(x,y,'o');

modelfun = @(p,x) p(1)./(1.0 + exp(-(p(2).*(x - p(3)))));

% YOU MUST ADJUST THE FOLLOWING LINE
% startingVals = [10,0.03,1985]; %Estimates for all parameters in the modelfun
startingVals = [7000,0.3,2008]; %Estimates for all parameters in the modelfun

[coefEsts,R,J] = nlinfit(x,y,modelfun,startingVals);
disp(' ');
disp('Estimated Coefficienst'); disp(coefEsts);

% YOU MUST ADJUST THE FOLLOWING LINE
%xgrid = linspace(1900,2100,100); %Start, end and nr of points. Refer to data
xgrid = linspace(1980,2010,100); %Start, end and nr of points. Refer to data

line(xgrid,modelfun(coefEsts,xgrid), 'Color','r');

disp(' ' );
disp('95% confidence intervals for parameters');
bci = nlparci(coefEsts,R,J);
disp(bci);

f = modelfun(coefEsts,x);

disp(' ' );
disp('rms error = ');
err = y - f;
err2 = err.^2;
mse = mean(err2);
rmse = sqrt(mse);
disp(rmse);

ssResid = sum(R.^2);
ssTotal = sum((y-mean(y)).^2);
r2 = 1 - (ssResid/ssTotal);
disp('  ');
disp('r2 value = '); disp(r2);
